# gcc

compile main.c (default executable output is a.out)

    gcc main.c


compile main.c into an outfile file main.o

    gcc main.c -o main.o


compile main.c and enable all warnings

    gcc -Wall main.c


compile main.c but do not run the linker

    gcc -c main.c



# Basic Usage

Compile a file using the GNU compiler: 

    gcc <file>


